==> EntitySyncer-0.0.2-sources.jar: org/openzen/entitysyncer/live/field/LiveDoubleField.java <==
/*
 * To change this license header, choose License Headers in Project Properties.
 * To change this template file, choose Tools | Templates
 * and open the template in the editor.
 */
package org.openzen.entitysyncer.live.field;

import org.openzen.entitysyncer.live.LiveDouble;
import org.openzen.entitysyncer.structured.StructuredObject;

/**
 *
 * @author Hoofdgebruiker
 */
public class LiveDoubleField extends LiveBaseField implements LiveDouble {
	private double value;
	
	public LiveDoubleField(double value) {
		this.value = value;
	}
	
	@Override
	public double get() {
		return value;
	}
	
	public void set(double value) {
		this.value = value;
		publish();
	}

	@Override
	public boolean asBoolValue() {
		return value != 0;
	}

	@Override
	public int asIntValue() {
		return (int) value;
	}

	@Override
	public long asLongValue() {
		return (long) value;
	}

	@Override
	public float asFloatValue() {
		return (float) value;
	}
	
	@Override
	public LiveDouble asDouble() {
		return this;
	}

	@Override
	public double asDoubleValue() {
		return value;
	}

	@Override
	public String asStringValue() {
		return Double.toString(value);
	}

	@Override
	public StructuredObject asObjectValue() {
		throw new ClassCastException("Cannot cast double to an object");
	}

	@Override
	public void setBool(boolean value) {
		set(value ? 1 : 0);
	}

	@Override
	public void setInt(int value) {
		set(value);
	}

	@Override
	public void setLong(long value) {
		set(value);
	}

	@Override
	public void setFloat(float value) {
		set(value);
	}

	@Override
	public void setDouble(double value) {
		set(value);
	}

	@Override
	public void setString(String value) {
		set(Double.parseDouble(value));
	}

	@Override
	public void setObject(StructuredObject value) {
		throw new ClassCastException("Cannot cast object to double");
	}
}

==> EntitySyncer-0.0.7-sources.jar: org/openzen/entitysyncer/live/field/LiveDoubleField.java <==
/*
 * To change this license header, choose License Headers in Project Properties.
 * To change this template file, choose Tools | Templates
 * and open the template in the editor.
 */
package org.openzen.entitysyncer.live.field;

import org.openzen.entitysyncer.live.LiveDouble;
import org.openzen.entitysyncer.structured.StructuredObject;
import org.openzen.entitysyncer.structured.definition.DoubleFieldType;
import org.openzen.entitysyncer.structured.definition.StructuredFieldType;

/**
 *
 * @author Hoofdgebruiker
 */
public class LiveDoubleField extends LiveBaseNumberField implements LiveDouble {
	private double value;
	
	public LiveDoubleField(double value) {
		this.value = value;
	}
	
	@Override
	public double get() {
		return value;
	}
	
	public void set(double value) {
		this.value = value;
		publish();
	}
	
	@Override
	public void clear() {
		set(0);
	}
	
	@Override
	public StructuredFieldType getType() {
		return DoubleFieldType.INSTANCE;
	}

	@Override
	public boolean asBoolValue() {
		return value != 0;
	}

	@Override
	public int asIntValue() {
		return (int) value;
	}

	@Override
	public long asLongValue() {
		return (long) value;
	}

	@Override
	public float asFloatValue() {
		return (float) value;
	}
	
	@Override
	public LiveDouble asDouble() {
		return this;
	}

	@Override
	public double asDoubleValue() {
		return value;
	}

	@Override
	public String asStringValue() {
		return Double.toString(value);
	}

	@Override
	public StructuredObject asObjectValue() {
		throw new ClassCastException("Cannot cast double to an object");
	}

	@Override
	public void setBool(boolean value) {
		set(value ? 1 : 0);
	}

	@Override
	public void setInt(int value) {
		set(value);
	}

	@Override
	public void setLong(long value) {
		set(value);
	}

	@Override
	public void setFloat(float value) {
		set(value);
	}

	@Override
	public void setDouble(double value) {
		set(value);
	}

	@Override
	public void setString(String value) {
		set(Double.parseDouble(value));
	}

	@Override
	public void setObject(StructuredObject value) {
		throw new ClassCastException("Cannot cast object to double");
	}
}
